Package org.openpdf.html
Record Class HtmlToPdfBatchUtils.HtmlFileJob
java.lang.Object
java.lang.Record
org.openpdf.html.HtmlToPdfBatchUtils.HtmlFileJob
- Enclosing class:
HtmlToPdfBatchUtils
public static record HtmlToPdfBatchUtils.HtmlFileJob(Path htmlFile, Path baseDir, Path output, Optional<String> injectCss, Optional<Consumer<ITextRenderer>> rendererCustomizer)
extends Record
Render an HTML file (and its relative assets) to PDF.
-
Constructor Summary
ConstructorsConstructorDescriptionHtmlFileJob(Path htmlFile, Path baseDir, Path output, Optional<String> injectCss, Optional<Consumer<ITextRenderer>> rendererCustomizer) Creates an instance of aHtmlFileJobrecord class. -
Method Summary
Modifier and TypeMethodDescriptionbaseDir()Returns the value of thebaseDirrecord component.final booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.htmlFile()Returns the value of thehtmlFilerecord component.Returns the value of theinjectCssrecord component.output()Returns the value of theoutputrecord component.Returns the value of therendererCustomizerrecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
HtmlFileJob
public HtmlFileJob(Path htmlFile, Path baseDir, Path output, Optional<String> injectCss, Optional<Consumer<ITextRenderer>> rendererCustomizer) Creates an instance of aHtmlFileJobrecord class.- Parameters:
htmlFile- the value for thehtmlFilerecord componentbaseDir- the value for thebaseDirrecord componentoutput- the value for theoutputrecord componentinjectCss- the value for theinjectCssrecord componentrendererCustomizer- the value for therendererCustomizerrecord component
-
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
htmlFile
Returns the value of thehtmlFilerecord component.- Returns:
- the value of the
htmlFilerecord component
-
baseDir
Returns the value of thebaseDirrecord component.- Returns:
- the value of the
baseDirrecord component
-
output
Returns the value of theoutputrecord component.- Returns:
- the value of the
outputrecord component
-
injectCss
Returns the value of theinjectCssrecord component.- Returns:
- the value of the
injectCssrecord component
-
rendererCustomizer
Returns the value of therendererCustomizerrecord component.- Returns:
- the value of the
rendererCustomizerrecord component
-