Record Class HtmlToPdfBatchUtils.HtmlStringJob

java.lang.Object
java.lang.Record
org.openpdf.html.HtmlToPdfBatchUtils.HtmlStringJob
Enclosing class:
HtmlToPdfBatchUtils

public static record HtmlToPdfBatchUtils.HtmlStringJob(String html, String baseUri, Path output, Optional<String> injectCss, Optional<Consumer<ITextRenderer>> rendererCustomizer) extends Record
Render raw HTML string to PDF.
  • Constructor Details

    • HtmlStringJob

      public HtmlStringJob(String html, String baseUri, Path output, Optional<String> injectCss, Optional<Consumer<ITextRenderer>> rendererCustomizer)
      Creates an instance of a HtmlStringJob record class.
      Parameters:
      html - the value for the html record component
      baseUri - the value for the baseUri record component
      output - the value for the output record component
      injectCss - the value for the injectCss record component
      rendererCustomizer - the value for the rendererCustomizer record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • html

      public String html()
      Returns the value of the html record component.
      Returns:
      the value of the html record component
    • baseUri

      public String baseUri()
      Returns the value of the baseUri record component.
      Returns:
      the value of the baseUri record component
    • output

      public Path output()
      Returns the value of the output record component.
      Returns:
      the value of the output record component
    • injectCss

      public Optional<String> injectCss()
      Returns the value of the injectCss record component.
      Returns:
      the value of the injectCss record component
    • rendererCustomizer

      public Optional<Consumer<ITextRenderer>> rendererCustomizer()
      Returns the value of the rendererCustomizer record component.
      Returns:
      the value of the rendererCustomizer record component