Uses of Class
org.openpdf.resource.HtmlParserConfig.Builder
Packages that use HtmlParserConfig.Builder
-
Uses of HtmlParserConfig.Builder in org.openpdf.resource
Methods in org.openpdf.resource that return HtmlParserConfig.BuilderModifier and TypeMethodDescriptionHtmlParserConfig.Builder.allowSelfClosingIframe(boolean allowSelfClosingIframe) Enable or disable self-closing iframe tags.HtmlParserConfig.Builder.allowSelfClosingTags(boolean allowSelfClosingTags) Enable or disable XHTML-style self-closing tags.HtmlParserConfig.Builder.attributeNameCase(@Nullable String attributeNameCase) Set the attribute name case handling.static HtmlParserConfig.BuilderHtmlParserConfig.builder()Creates a new configuration builder.HtmlParserConfig.Builder.elementNameCase(@Nullable String elementNameCase) Set the element name case handling.Set the default character encoding.HtmlParserConfig.Builder.parseNoScriptContent(boolean parseNoScriptContent) Enable or disable parsing of noscript content as markup.HtmlParserConfig.Builder.reportErrors(boolean reportErrors) Enable or disable error reporting during parsing.HtmlParserConfig.Builder.scriptStripCommentDelims(boolean scriptStripCommentDelims) Enable or disable stripping of comment delimiters from script content.HtmlParserConfig.Builder.styleStripCommentDelims(boolean styleStripCommentDelims) Enable or disable stripping of comment delimiters from style content.