Package org.openpdf.resource
@NullMarked
package org.openpdf.resource
-
ClassDescriptionFSCatalog loads an XML catalog file to read mappings of public IDs for XML schemas/dtds, to resolve those mappings to a local store for the schemas.A SAX EntityResolver for common entity references and DTDs in X/HTML processing.Configuration options for the htmlunit-neko HTML parser.Builder for creating HtmlParserConfig instances.HtmlResource provides HTML5-compliant parsing using htmlunit-neko's DOMParser.