Record Class HtmlToPdfBatchUtils.UrlJob
java.lang.Object
java.lang.Record
org.openpdf.html.HtmlToPdfBatchUtils.UrlJob
- Enclosing class:
HtmlToPdfBatchUtils
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.Returns the value of theinjectCssrecord component.output()Returns the value of theoutputrecord component.Returns the value of therendererCustomizerrecord component.final StringtoString()Returns a string representation of this record class.url()Returns the value of theurlrecord component.
-
Constructor Details
-
UrlJob
public UrlJob(String url, Path output, Optional<String> injectCss, Optional<Consumer<ITextRenderer>> rendererCustomizer) Creates an instance of aUrlJobrecord class.- Parameters:
url- the value for theurlrecord componentoutput- the value for theoutputrecord componentinjectCss- the value for theinjectCssrecord componentrendererCustomizer- the value for therendererCustomizerrecord component
-
-
Method Details
-
toString
-
hashCode
-
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
url
Returns the value of theurlrecord component.- Returns:
- the value of the
urlrecord component
-
output
Returns the value of theoutputrecord component.- Returns:
- the value of the
outputrecord component
-
injectCss
-
rendererCustomizer
Returns the value of therendererCustomizerrecord component.- Returns:
- the value of the
rendererCustomizerrecord component
-